@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "hindent" "6.3.0"
+(define-package "hindent" "20250909.1613"
   "Indent haskell code using the \"hindent\" program."
   '((emacs "27.1"))
   :url "https://github.com/mihaimaruseac/hindent"
-  :commit "57e769d48447c77da5a21d1923ba3634e3a605fe"
-  :revdesc "57e769d48447"
+  :commit "e841f55c37abf6865309083b93eb6214eb100cea"
+  :revdesc "e841f55c37ab"
   :authors '(("Chris Done" . "chrisdone@gmail.com"))
   :maintainers '(("Chris Done" . "chrisdone@gmail.com")))
